/*
 * SSSOM-Java - SSSOM library for Java
 * Copyright © 2023 Damien Goutte-Gattat
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the Gnu General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package org.incenp.obofoundry.sssom.transform;

import org.incenp.obofoundry.sssom.model.Mapping;

/**
 * A listener invoked by the {@link MappingProcessor} engine when a rule is
 * applied to a mapping and results in the production of an object.
 *
 * @param <T> The type of object generated by the mapping processing rule.
 */
public interface IMappingProcessorListener<T> {

    /**
     * This method is called whenever a rule is applied to a mapping and produces an
     * object.
     * 
     * @param rule    The rule that is being applied.
     * @param mapping The mapping the rule is being applied to.
     * @param product The object produced by the rule when applied to this
     *                particular mapping.
     */
    public void generated(MappingProcessingRule<T> rule, Mapping mapping, T product);

}
